@@ -19,6 +19,7 @@ from messager.utils import MISSING_DST_TIMEZONE, MISSING_DATE, MISSING_VALUE
 from time import tzname
 from datetime import datetime
 import json
+import smtplib
 
 
 def validate_message(message):
@@ -228,3 +229,35 @@ class RabbitMQMessager(object):
             # If something goes wrong we pass silently
             msg = "Something goes wrong: %s" % excpt
             self.logger.error(msg)
+
+    def send_email(self, options, gmail_username, gmail_password):
+        """Method that send an email using gmail SMTP
+
+            :param target: Dict containing subject, body, e-mail target.
+            :type target: Dict.
+
+            :param gmail_username: Gmail username account.
+            :type gmail_username: str.
+
+            :param gmail_password: Password of gmail account.
+            :type gmail_password: str.
+        """
+        headers = ["From: %s" % gmail_username,
+                   "Subject: %s" % options["subject"],
+                   "To: %s" % options["target"],
+                   "MIME-Version: 1.0",
+                   "Content-Type: text/html"]
+        headers = "\r\n".join(headers)
+
+        message = "%s\r\n\r\n%s" % (headers, options["body"])
+
+        smtp_url = "smtp.gmail.com:587"
+
+        log_message = "\n%s" % message
+        self.logger.error(log_message)
+
+        server = smtplib.SMTP(smtp_url)
+        server.starttls()
+        server.login(gmail_username, gmail_password)
+        server.sendmail(options["target"], options["target"], message)
+        server.quit()
